TaskCancelled class final
Task was cancelled by user request.
- Inheritance
-
- Object
- TaskStatus
- TaskCancelled
- Annotations
Constructors
- TaskCancelled({required String executionId, required String taskName})
-
const
Properties
- executionId → String
-
Unique ID for this task execution.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskName → String
-
Name of the registered task.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited