thenAll method
Adds multiple tasks to run in parallel.
All tasks in the list will receive the same input as previous step. The chain waits for all parallel tasks to complete before proceeding to the next sequential step.
Implementation
TaskChain thenAll(List<String> taskNames) {
_steps.add(_RawChainStep.parallel(taskNames));
return this;
}