withRetry method
Sets retry policy for all steps in the chain.
Implementation
TaskChain withRetry(RetryPolicy retry) {
this.retry = retry;
return this;
}
Sets retry policy for all steps in the chain.
TaskChain withRetry(RetryPolicy retry) {
this.retry = retry;
return this;
}