batteryNotLow property
Task will only run if device battery is not low.
Android: setRequiresBatteryNotLow(true).
iOS: checked in Dart before execution.
Implementation
final bool batteryNotLow;
Task will only run if device battery is not low.
Android: setRequiresBatteryNotLow(true).
iOS: checked in Dart before execution.
final bool batteryNotLow;