TaskEncryption class abstract

Task data encryption at rest.

Encrypt sensitive input/output data for PII, financial, or health data. Keys are stored in platform keychain (Keystore on Android, Keychain on iOS).

Example:

await TaskFlow.enqueue(
  'processPayment',
  input: {'cardNumber': '4532-1111-2222-3333'},
  encryption: TaskEncryption.aes256,
);

Constructors

TaskEncryption()

Properties

algorithm String
Encryption algorithm
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(String ciphertext) String
Decrypt data
encrypt(String plaintext) String
Encrypt data
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

aes256 TaskEncryption
AES-256 GCM encryption (recommended for production)
final
none TaskEncryption
No encryption (development only)
final