TaskFailed class final

Task failed after exhausting retries.

Inheritance
Annotations

Constructors

TaskFailed({required String executionId, required String taskName, String? error, required int attempt, required int maxAttempts})
const

Properties

attempt int
The attempt number that failed.
final
error String?
Error message if any.
final
executionId String
Unique ID for this task execution.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
Maximum retries configured.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskName String
Name of the registered task.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited