TaskFailure class final

Task failed.

Inheritance
Annotations

Constructors

TaskFailure({String? message, Object? error})
const

Properties

error Object?
Optional exception object.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
Optional error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited