TaskHandlerNotFoundException class

Thrown when TaskFlow.enqueue references a handler that was not registered.

Inheritance

Constructors

TaskHandlerNotFoundException(String handlerName)

Properties

code String?
Optional error code for platform-specific exceptions.
finalinherited
handlerName String
The name of the handler that was not found.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited