TaskPriority enum
Priority level for a background task.
Values
- high → const TaskPriority
-
High priority. Android: uses setExpedited(). iOS: uses BGAppRefreshTask.
- normal → const TaskPriority
-
Normal priority. Android: OneTimeWorkRequest. iOS: BGProcessingTask.
- low → const TaskPriority
-
Low priority. Android: OneTimeWorkRequest with idle constraint. iOS: BGProcessingTask with requiresExternalPower.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TaskPriority> - A constant List of the values in this enum, in order of their declaration.