TaskRetrying class final

Task failed but will retry after nextAttempt.

Inheritance
Annotations

Constructors

TaskRetrying({required String executionId, required String taskName, required DateTime nextAttempt, required int attempt})
const

Properties

attempt int
Current attempt number.
final
executionId String
Unique ID for this task execution.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
nextAttempt DateTime
When the next attempt will be scheduled.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskName String
Name of the registered task.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited