TaskRunning class final

Task is currently running.

Inheritance
Annotations

Constructors

TaskRunning({required String executionId, required String taskName, required double progress})
const

Properties

executionId String
Unique ID for this task execution.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
progress double
Progress 0.0–1.0 reported by the task handler.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskName String
Name of the registered task.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited