TaskSucceeded class final

Task completed successfully.

Inheritance
Annotations

Constructors

TaskSucceeded({required String executionId, required String taskName, Map<String, dynamic>? data})
const

Properties

data Map<String, dynamic>?
Output data returned by the task handler.
final
executionId String
Unique ID for this task execution.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskName String
Name of the registered task.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited