methodChannel constant
The method channel used to interact with the native platform.
Implementation
@visibleForTesting
static const methodChannel = MethodChannel('dev.taskflow/channel');
The method channel used to interact with the native platform.
@visibleForTesting
static const methodChannel = MethodChannel('dev.taskflow/channel');