TaskContext class final
Context passed to a task handler when it executes.
- Annotations
Constructors
Properties
- attempt → int
-
Current attempt number (1-based).
final
- executionId → String
-
Unique ID for this task execution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, dynamic> -
Input data passed when enqueueing.
final
-
previousOutput
→ Map<
String, dynamic> ? -
Output from the previous chain step, or null if this is the first step.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskName → String
-
The registered task name.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reportProgress(
double progress) → Future< void> - Reports task progress (0.0–1.0) to be streamed to listeners.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited