TaskFlowDataSizeException class
Thrown when input/output data exceeds platform limits.
- Inheritance
-
- Object
- TaskFlowException
- TaskFlowDataSizeException
Constructors
- TaskFlowDataSizeException({required int actualBytes, required int maxBytes})
Properties
- actualBytes → int
-
The actual size in bytes.
final
- code → String?
-
Optional error code for platform-specific exceptions.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBytes → int
-
The maximum allowed size in bytes.
final
- message → String
-
The error message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited