TaskInfo class final
Information about a registered or queued task.
- Annotations
Constructors
Properties
- executionId → String
-
Unique execution ID.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
The registered task name.
final
- priority → String
-
Priority of this task.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduledAt → DateTime?
-
When the task is/was scheduled to run, or null if not scheduled yet.
final
- status → TaskStatus
-
Current status.
final
-
Tags associated with this task.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override