TaskRegistry class final
Registry of task handlers. Singleton.
Constructors
- TaskRegistry.instance()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
registeredNames
→ Iterable<
String> -
Returns all registered task names.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clears all registered handlers (used in tests).
-
contains(
String name) → bool -
Returns true if a handler with
nameis registered. -
lookup(
String name) → TaskHandler - Looks up a handler by name.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
String name, TaskHandler handler) → void - Registers a handler for a task name.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited