TaskResult class sealed
Result of executing a background task handler.
Sealed so callers must handle all cases exhaustively.
- Implementers
Constructors
- TaskResult.failure({String? message, Object? error})
-
Task failed permanently.
constfactory
-
TaskResult.retryLater(Duration delay, {Map<
String, dynamic> ? data}) -
Task needs to retry after a custom delay.
constfactory
-
TaskResult.success({Map<
String, dynamic> ? data}) -
Task completed successfully.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited