TaskRetryLater class final
Task should retry after a custom delay.
- Inheritance
-
- Object
- TaskResult
- TaskRetryLater
- Annotations
Constructors
-
TaskRetryLater(Duration delay, {Map<
String, dynamic> ? data}) -
const
Properties
-
data
→ Map<
String, dynamic> ? -
Optional output data passed to next step (if this is a chain).
final
- delay → Duration
-
How long to wait before retrying.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited